beobench.utils
==============

.. automodule:: beobench.utils

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      check_if_in_notebook
      merge_dicts
      restart
      shutdown
   
   

   
   
   

   
   
   



